@@ -1,19 +1,32 @@
+from re import L
 import sympy
 from mathpad import *
 
 
-def sin(x: Q[Angle]):
+def sin(x: Q[Angle]) -> Dimensionless:
     return Dimensionless(1, sympy.sin(x.val))  # type: ignore
 
 
-def cos(x: Q[Angle]):
+def cos(x: Q[Angle]) -> Dimensionless:
     return Dimensionless(1, sympy.cos(x.val))  # type: ignore
 
 
-def tan(x: Q[Angle]):
+def tan(x: Q[Angle]) -> Dimensionless:
     return Dimensionless(1, sympy.tan(x.val))  # type: ignore
 
 
+def magnitude(*xs: Q[GenericVal]) -> GenericVal:
+    "x's are lengths in orthogonal directions. ie (i, j k)"
+    c_2 = 0
+    for x in xs:
+        c_2 += x ** 2
+    return sqrt(c_2)
+
+
+def hypotenuse(a: Q[Length], b: Q[Length]) -> Length:
+    return cartesian_distance(a, b)
+
+
 # TODO: add more trig functions
 
 
